==> apache-camel-4.0.2-src.zip: apache-camel-4.0.2/components/camel-aws/camel-aws2-sns/src/main/java/org/apache/camel/component/aws2/sns/client/Sns2ClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.sns.client;

import org.apache.camel.component.aws2.sns.Sns2Configuration;
import org.apache.camel.component.aws2.sns.client.impl.Sns2ClientIAMOptimized;
import org.apache.camel.component.aws2.sns.client.impl.Sns2ClientIAMProfileOptimized;
import org.apache.camel.component.aws2.sns.client.impl.Sns2ClientStandardImpl;

/**
 * Factory class to return the correct type of AWS SNS aws.
 */
public final class Sns2ClientFactory {

    private Sns2ClientFactory() {
    }

    /**
     * Return the correct aws SNS client (based on remote vs local).
     *
     * @param  configuration configuration
     * @return               SNSClient
     */
    public static Sns2InternalClient getSnsClient(Sns2Configuration configuration) {
        if (Boolean.TRUE.equals(configuration.isUseDefaultCredentialsProvider())) {
            return new Sns2ClientIAMOptimized(configuration);
        } else if (Boolean.TRUE.equals(configuration.isUseProfileCredentialsProvider())) {
            return new Sns2ClientIAMProfileOptimized(configuration);
        } else {
            return new Sns2ClientStandardImpl(configuration);
        }
    }
}

==> apache-camel-4.10.7-src.zip: apache-camel-4.10.7/components/camel-aws/camel-aws2-sns/src/main/java/org/apache/camel/component/aws2/sns/client/Sns2ClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.sns.client;

import org.apache.camel.component.aws2.sns.Sns2Configuration;
import org.apache.camel.component.aws2.sns.client.impl.Sns2ClientIAMOptimized;
import org.apache.camel.component.aws2.sns.client.impl.Sns2ClientIAMProfileOptimized;
import org.apache.camel.component.aws2.sns.client.impl.Sns2ClientSessionTokenImpl;
import org.apache.camel.component.aws2.sns.client.impl.Sns2ClientStandardImpl;

/**
 * Factory class to return the correct type of AWS SNS aws.
 */
public final class Sns2ClientFactory {

    private Sns2ClientFactory() {
    }

    /**
     * Return the correct aws SNS client (based on remote vs local).
     *
     * @param  configuration configuration
     * @return               SNSClient
     */
    public static Sns2InternalClient getSnsClient(Sns2Configuration configuration) {
        if (Boolean.TRUE.equals(configuration.isUseDefaultCredentialsProvider())) {
            return new Sns2ClientIAMOptimized(configuration);
        } else if (Boolean.TRUE.equals(configuration.isUseProfileCredentialsProvider())) {
            return new Sns2ClientIAMProfileOptimized(configuration);
        } else if (Boolean.TRUE.equals(configuration.isUseSessionCredentials())) {
            return new Sns2ClientSessionTokenImpl(configuration);
        } else {
            return new Sns2ClientStandardImpl(configuration);
        }
    }
}
